@@ -59,6 +59,7 @@
 #include <apt-pkg/pkgcache.h>
 #include <apt-pkg/versionmatch.h>
 #include <apt-pkg/version.h>
+#include <apt-pkg/policy.h>
 
 #ifdef WITH_LUA
 #include <apt-pkg/luaiface.h>
@@ -825,6 +826,7 @@ void RPackage::setInstall()
       Fix.Protect(*_package);
       Fix.Resolve(true);
    }
+
 #ifdef WITH_LUA
    _lua->SetDepCache(_depcache);
    _lua->SetGlobal("package", ((pkgCache::Package *) * _package));
@@ -948,7 +950,7 @@ void RPackage::setPinned(bool flag)
    char *filename = NULL;
    struct stat stat_buf;
 
-   string File = _config->FindFile("Dir::Etc::Preferences");
+   string File =RConfDir() + "/preferences";
 
    _boolFlags = flag ? (_boolFlags | FPinned) : (_boolFlags & FPinned);
 
@@ -960,7 +962,12 @@ void RPackage::setPinned(bool flag)
       // write to pin-file
       ofstream out(File.c_str(), ios::app);
       out << "Package: " << name() << endl;
-      out << "Pin: version " << installedVersion() << endl;
+      // if the package is not installed, we pin it to the available version
+      // and prevent installation of this package this way
+      if(installedVersion() != NULL) 
+	 out << "Pin: version " << installedVersion() << endl;
+      else
+	 out << "Pin: version " << " 0.0 " << endl;
       out << "Pin-Priority: "
          << _config->FindI("Synaptic::DefaultPinPriority", 1001)
          << endl << endl;
@@ -1077,8 +1084,17 @@ bool RPackage::setVersion(string verTag)
 
    _depcache->SetCandidateVersion(Ver);
 
+   _boolFlags |= FOverrideVersion;
+
    return true;
 }
+ 
+void RPackage::unsetVersion() 
+{ 
+   //cout << "set version to " << _defaultCandVer << endl;
+   setVersion(_defaultCandVer); 
+   _boolFlags &= ~FOverrideVersion;
+}
 
 vector<string> RPackage::provides()
 {
@@ -1160,7 +1176,8 @@ void RPackage::setRemoveWithDeps(bool shallow, bool purge)
 // description parser stuff
 static char *debParser(string descr)
 {
-   unsigned int i,nlpos=0;
+   unsigned int i;
+   string::size_type nlpos=0;
 
    nlpos = descr.find('\n');
    // delete first line
@@ -1197,7 +1214,7 @@ static char *debParser(string descr)
 }
 static char *rpmParser(string descr)
 {
-   unsigned int pos = descr.find('\n');
+   string::size_type pos = descr.find('\n');
    // delete first line
    if (pos != string::npos)
       descr.erase(0, pos + 2);  // del "\n " too
