@@ -148,7 +148,7 @@ bool RPackageLister::setSubView(string newSubView)
 static string getServerErrorMessage(string errm)
 {
    string msg;
-   unsigned int pos = errm.find("server said");
+   string::size_type pos = errm.find("server said");
    if (pos != string::npos) {
       msg = string(errm.c_str() + pos + sizeof("server said"));
       if (msg[0] == ' ')
@@ -363,6 +363,8 @@ bool RPackageLister::openCache(bool reset)
 	 pkg->setNew(true);
       }
 
+      if (_roptions->getPackageLock(pkgName.c_str())) 
+	 pkg->setPinned(true);
 
       for (unsigned int i = 0; i != _views.size(); i++)
          _views[i]->addPackage(pkg);
@@ -404,9 +406,6 @@ void RPackageLister::applyInitialSelection()
 
    for (unsigned i = 0; i < _packages.size(); i++) {
 
-      if (_roptions->getPackageLock(_packages[i]->name()))
-         _packages[i]->setPinned(true);
-
       if (_roptions->getPackageOrphaned(_packages[i]->name()))
          _packages[i]->setOrphaned(true);
    }
@@ -1252,6 +1251,10 @@ bool RPackageLister::commitChanges(pkgAcquireStatus *status,
 
          string errm = (*I)->ErrorText;
 	 ostringstream tmp;
+    // TRANSLATORS: Error message after a failed download.
+    //              The first %s is the URL and the second 
+    //              one is a detailed error message that
+    //              is provided by apt
 	 ioprintf(tmp, _("Failed to fetch %s\n  %s"), 
 		  (*I)->DescURI().c_str(), errm.c_str());
 
