@@ -111,7 +111,9 @@ class RPackageLister {
    typedef enum {
       LIST_SORT_NAME,
       LIST_SORT_SIZE_ASC,
-      LIST_SORT_SIZE_DES
+      LIST_SORT_SIZE_DES,
+      LIST_SORT_STATUS_ASC,
+      LIST_SORT_STATUS_DES
    } listSortMode;
    listSortMode _sortMode;
 
@@ -130,6 +132,7 @@ class RPackageLister {
 
    bool lockPackageCache(FileFd &lock);
 
+   void sortPackagesByStatus(vector<RPackage *> &packages, int order);
    void sortPackagesByName(vector<RPackage *> &packages);
    void sortPackagesByInstSize(vector<RPackage *> &packages, int order);
 
@@ -150,7 +153,9 @@ class RPackageLister {
    list<pkgState> redoStack;
 
    public:
-
+   void sortPackagesByStatus(int order) {
+      sortPackagesByStatus(_viewPackages, order);
+   };
    void sortPackagesByName() {
       sortPackagesByName(_viewPackages);
    };
