@@ -113,6 +113,10 @@ int main(int argc, char **argv)
    bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
    bindtextdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
    textdomain(GETTEXT_PACKAGE);
+
+#ifdef HAVE_RPM
+   bind_textdomain_codeset("rpm", "UTF-8");
+#endif
 #endif
 
    gtk_init(&argc, &argv);
