@@ -24,21 +24,38 @@
 #ifndef _RGGLADEWINDOW_H_
 #define _RGGLADEWINDOW_H_
 
+#include "config.h"
+
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 #include <string>
 #include <iostream>
+
 #include "rgwindow.h"
+#include "rgmisc.h"
 
 using namespace std;
 
-class RGGladeWindow : public RGWindow {   
-protected:
+class RGGladeWindow:public RGWindow {
+ protected:
    GladeXML *_gladeXML;
-   
-public:
-   RGGladeWindow(RGWindow *parent, string name, string main_widget="");
+
+ public:
+   RGGladeWindow(RGWindow *parent, string name, string main_widget = "");
+
+   void skipTaskbar(bool value) {
+      gtk_window_set_skip_taskbar_hint(GTK_WINDOW(_win), value);
+   }
+
+   // functions to set various widgets
+   bool setLabel(const char *name, const char *value);
+   bool setLabel(const char *name, const long value);
+   bool setTextView(const char *widget_name, const char *value,
+		    bool useHeadline=false);
+   bool setPixmap(const char *widget_name, GdkPixbuf *value);
+   bool setTreeList(const char *widget_name, vector<string> values,
+		    bool useMarkup=false);
+
 };
 
 #endif
-    
