@@ -354,9 +354,12 @@ void RGMainWindow::updatePackageInfo(RPackage *pkg)
    gtk_widget_set_sensitive(_dl_changelogM, FALSE);
    gtk_widget_set_sensitive(_detailsM, FALSE);
    gtk_widget_set_sensitive(_propertiesB, FALSE);
+   gtk_widget_set_sensitive(_overrideVersionM, FALSE);
+   gtk_widget_set_sensitive(_pinM, FALSE);
    gtk_text_buffer_set_text(_pkgCommonTextBuffer,
 			    _("No package is selected.\n"), -1);
 
+
    // return if no pkg is selected
    if (!pkg) 
       return;
@@ -370,6 +373,27 @@ void RGMainWindow::updatePackageInfo(RPackage *pkg)
    // set menu according to pkg status
    int flags = pkg->getFlags();
 
+   // changelog and properties are always visible
+   gtk_widget_set_sensitive(_dl_changelogM, TRUE);
+   gtk_widget_set_sensitive(_detailsM, TRUE);
+   gtk_widget_set_sensitive(_propertiesB, TRUE);
+   gtk_widget_set_sensitive(_pinM, TRUE);
+
+   if(_pkgDetails != NULL)
+      _pkgDetails->fillInValues(pkg);
+
+   // Pin, if a pin is set, we skip all other checks and return
+   if( flags & RPackage::FPinned) {
+      _blockActions = TRUE;
+      gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(_pinM), true);
+      _blockActions = FALSE;
+      return;
+   } else {
+      _blockActions = TRUE;
+      gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(_pinM), false);
+      _blockActions = FALSE;
+   }
+
    // enable unmark if a action is performed with the pkg
    if((flags & RPackage::FInstall)   || (flags & RPackage::FNewInstall) || 
       (flags & RPackage::FReInstall) || (flags & RPackage::FUpgrade) || 
@@ -401,10 +425,8 @@ void RGMainWindow::updatePackageInfo(RPackage *pkg)
 					pkg->dependsOn("debconf-i18n")))
        gtk_widget_set_sensitive(_pkgReconfigureM, TRUE);
 
-   // changelog and properties are always visible
-   gtk_widget_set_sensitive(_dl_changelogM, TRUE);
-   gtk_widget_set_sensitive(_detailsM, TRUE);
-   gtk_widget_set_sensitive(_propertiesB, TRUE);
+   if(pkg->getAvailableVersions().size() > 1)
+      gtk_widget_set_sensitive(_overrideVersionM, TRUE);
 
    // set the "keep" menu icon according to the current status
    GtkWidget *img;
@@ -414,48 +436,68 @@ void RGMainWindow::updatePackageInfo(RPackage *pkg)
       img = get_gtk_image("package-installed-updated");
    gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(_keepM), img);
 
-   if(_pkgDetails != NULL)
-      _pkgDetails->fillInValues(pkg);
-
    setStatusText();
 }
 
 
 // install a specific version
-void RGMainWindow::installFromVersion(GtkWidget *self, void *data)
+void RGMainWindow::cbInstallFromVersion(GtkWidget *self, void *data)
 {
-   RGMainWindow *me = (RGMainWindow *) g_object_get_data(G_OBJECT(self), "me");
-   RPackage *pkg = (RPackage *) g_object_get_data(G_OBJECT(self), "pkg");
-   gchar *verInfo = (gchar *) data;
+   //cout << "RGMainWindow::cbInstallFromVersion()" << endl;
 
-   // check if it's a interessting event
-   if (!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self))) {
+   RGMainWindow *me = (RGMainWindow *) data;
+   RPackage *pkg = me->selectedPackage();
+   if(pkg == NULL)
       return;
+
+   RGGladeUserDialog dia(me,"change_version");
+
+   GtkWidget *label = glade_xml_get_widget(dia.getGladeXML(),
+					   "label_text");
+   gchar *str_name = g_strdup_printf(_("Select the version of %s that should be forced for installation"), pkg->name());
+   gchar *str = g_strdup_printf("<big><b>%s</b></big>\n\n%s", str_name,
+				_("The package manager always selects the best version available. If you force a differnet version from the default one, errors in the dependency handling can occur."));
+   gtk_label_set_markup(GTK_LABEL(label), str);
+   g_free(str_name);
+   g_free(str);
+   
+   GtkWidget *optionMenu = glade_xml_get_widget(dia.getGladeXML(), 
+					"optionmenu_available_versions");
+
+   GtkWidget *menu = gtk_menu_new(); 
+   GtkWidget *item; 
+
+   int canidateNr = 0;
+   vector<pair<string, string> > versions = pkg->getAvailableVersions();
+   for(unsigned int i=0;i<versions.size();i++) {
+      gchar *str = g_strdup_printf("%s (%s)", 
+				   versions[i].first.c_str(), 
+				   versions[i].second.c_str() );
+      item = gtk_menu_item_new_with_label(str);
+      if(versions[i].first == pkg->availableVersion())
+	 canidateNr = i;
+      gtk_widget_show(item);
+      gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);
+      //cout << "got: " << str << endl;
+      g_free(str);
    }
-   // set pkg to "not installed" 
-   if (verInfo == NULL) {
-      pkg->unsetVersion();
-      me->pkgAction(PKG_DELETE);
-      return;
+   gtk_option_menu_set_menu(GTK_OPTION_MENU(optionMenu), menu);
+   gtk_option_menu_set_history(GTK_OPTION_MENU(optionMenu), canidateNr);
+   if(!dia.run()) {
+      //cout << "cancel" << endl;
+      return;    // user clicked cancel
    }
 
-   string instVer;
-   if (pkg->installedVersion() == NULL)
-      instVer = "";
-   else
-      instVer = pkg->installedVersion();
+   int nr = gtk_option_menu_get_history(GTK_OPTION_MENU(optionMenu));
 
    pkg->setNotify(false);
-   if (instVer == string(verInfo)) {
-      pkg->unsetVersion();
-      me->pkgAction(PKG_KEEP);
-   } else {
-      pkg->setVersion(verInfo);
-      me->pkgAction(PKG_INSTALL);
-
-      if (!(pkg->getFlags() & RPackage::FInstall))
-         pkg->unsetVersion();
-   }
+   // nr-1 here as we add a "do not override" to the option menu
+   pkg->setVersion(versions[nr].first.c_str());
+   me->pkgAction(PKG_INSTALL_FROM_VERSION);
+   
+   if (!(pkg->getFlags() & RPackage::FInstall))
+      pkg->unsetVersion();   // something went wrong
+   
    pkg->setNotify(true);
 }
 
@@ -552,6 +594,9 @@ void RGMainWindow::pkgAction(RGPkgAction action)
             instPkgs.push_back(pkg);
             pkgInstallHelper(pkg, false);
             break;
+         case PKG_INSTALL_FROM_VERSION:     // install with specific version
+            pkgInstallHelper(pkg, false);
+            break;
          case PKG_REINSTALL:      // reinstall
 	    instPkgs.push_back(pkg);
 	    pkgInstallHelper(pkg, false, true);
@@ -1077,6 +1122,7 @@ void RGMainWindow::buildInterface()
    _remove_w_depsM = glade_xml_get_widget(_gladeXML, "menu_remove_with_deps");
    assert(_remove_w_depsM);
 #endif
+
    _dl_changelogM = glade_xml_get_widget(_gladeXML, "menu_download_changelog");
    assert(_dl_changelogM);
 #ifdef HAVE_RPM
@@ -1160,12 +1206,20 @@ void RGMainWindow::buildInterface()
                                  "on_menu_pin",
                                  G_CALLBACK(cbMenuPinClicked), this);
 
+   _overrideVersionM = glade_xml_get_widget(_gladeXML, 
+					    "menu_override_version");
+   assert(_overrideVersionM);
+   glade_xml_signal_connect_data(_gladeXML,
+                                 "on_menu_override_version_activate",
+                                 G_CALLBACK(cbInstallFromVersion), this);
+
+
    // only if pkg help is enabled
 #ifndef SYNAPTIC_PKG_HOLD
    gtk_widget_hide(_pinM);
-   widget = glade_xml_get_widget(_gladeXML, "separator_hold");
-   if (widget != NULL)
-      gtk_widget_hide(widget);
+//    widget = glade_xml_get_widget(_gladeXML, "separator_hold");
+//    if (widget != NULL)
+//       gtk_widget_hide(widget);
 #endif
 
    _pkginfo = glade_xml_get_widget(_gladeXML, "box_pkginfo");
@@ -1354,7 +1408,7 @@ void RGMainWindow::buildInterface()
    gtk_menu_shell_append(GTK_MENU_SHELL(_popupMenu), menuitem);
 #endif
 
-   gtk_widget_show_all(_popupMenu);
+   gtk_widget_show(_popupMenu);
 
    // attach progress bar
    _progressBar = glade_xml_get_widget(_gladeXML, "progressbar_main");
@@ -1415,10 +1469,6 @@ void RGMainWindow::pkgRemoveHelper(RPackage *pkg, bool purge, bool withDeps)
       if (!_userDialog->confirm(_("Removing this package may render the "
                                   "system unusable.\n"
                                   "Are you sure you want to do that?"))) {
-         _blockActions = TRUE;
-         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(this->_currentB),
-                                      TRUE);
-         _blockActions = FALSE;
          return;
       }
    }
@@ -1703,6 +1753,18 @@ void RGMainWindow::cbChangelogDialog(GtkWidget *self, void *data)
    string filename = pkg->getChangelogFile(&fetcher);
    
    RGGladeUserDialog dia(me,"changelog");
+
+   // set title
+   GtkWidget *win = glade_xml_get_widget(dia.getGladeXML(), 
+					   "dialog_changelog");
+   assert(win);
+   // TRANSLATORS: Title of the changelog dialog - %s is the name of the package
+   gchar *str = g_strdup_printf(_("%s Changelog"), pkg->name());
+   gtk_window_set_title(GTK_WINDOW(win), str);
+   g_free(str);
+
+
+   // set changelog data
    GtkWidget *textview = glade_xml_get_widget(dia.getGladeXML(),
 					      "textview_changelog");
    assert(textview);
@@ -1715,7 +1777,10 @@ void RGMainWindow::cbChangelogDialog(GtkWidget *self, void *data)
    ifstream in(filename.c_str());
    string s;
    while(getline(in, s)) {
-      gtk_text_buffer_insert_at_cursor(buffer, s.c_str(), -1);
+      // no need to free str later, it is allocated in a static buffer
+      const char *str = utf8(s.c_str());
+      if(str!=NULL)
+	 gtk_text_buffer_insert_at_cursor(buffer, str, -1);
       gtk_text_buffer_insert_at_cursor(buffer, "\n", -1);
    }
    
@@ -1744,6 +1809,9 @@ void RGMainWindow::cbPackageListRowActivated(GtkTreeView *treeview,
 
    int flags = pkg->getFlags();
 
+   if(flags & RPackage::FPinned)
+      return;
+
    if (!(flags & RPackage::FInstalled)) {
       if (flags & RPackage::FKeep)
          me->pkgAction(PKG_INSTALL);
@@ -2100,6 +2168,8 @@ void RGMainWindow::cbSelectedRow(GtkTreeSelection *selection, gpointer data)
    RPackage *pkg;
    GList *li, *list;
 
+
+
    //cout << "RGMainWindow::cbSelectedRow()" << endl;
 
    if (me->_pkgList == NULL) {
@@ -2635,6 +2705,8 @@ void RGMainWindow::cbMenuPinClicked(GtkWidget *self, void *data)
 
    me->_lister->registerObserver(me);
    me->setTreeLocked(FALSE);
+   string currentSubView = me->selectedSubView();
+   me->refreshSubViewList(currentSubView);
    me->refreshTable();
    me->setInterfaceLocked(FALSE);
 }
@@ -2654,6 +2726,9 @@ void RGMainWindow::cbTreeviewPopupMenu(GtkWidget *treeview,
 
    int flags = pkg->getFlags();
 
+   if( flags & RPackage::FPinned) 
+      return;
+
    // Gray out buttons that don't make sense, and update image
    // if necessary.
    GList *item = gtk_container_get_children(GTK_CONTAINER(me->_popupMenu));
